@@ -44,7 +44,7 @@ def quadrantmean(data: np.ndarray, x: np.ndarray, y: np.ndarray,
     """
     if np.ndim(data) != 2:
         print('data must be 2D.')
-        return -1
+        return
 
     dx, dy = x[1] - x[0], y[1] - y[0]
     nx = int(np.floor(max(np.abs(x[0]), np.abs(x[-1])) / dx))
@@ -80,7 +80,7 @@ def RGIxy(y: np.ndarray, x: np.ndarray, data: np.ndarray,
     """
     if not np.ndim(data) in [2, 3, 4]:
         print('data must be 2D, 3D, or 4D.')
-        return -1
+        return
 
     c4d = to4dim(data)
     c4d[np.isnan(c4d)] = 0
@@ -113,7 +113,7 @@ def RGIxyv(v: np.ndarray, y: np.ndarray, x: np.ndarray, data: np.ndarray,
     """
     if not np.ndim(data) in [3, 4]:
         print('data must be 3D or 4D.')
-        return -1
+        return
 
     c4d = to4dim(data)
     c4d[np.isnan(c4d)] = 0
@@ -200,6 +200,7 @@ class AstroData():
         self.bunit = ''
         self.fitsimage_org = None
         self.sigma_org = None
+        self.beam_org = None
         self.fitsheader = None
         self.pv = False
 
@@ -267,7 +268,7 @@ class AstroData():
         """
         if None in self.beam:
             print('No beam.')
-            return False
+            return
 
         bmaj, bmin, bpa = self.beam
         self.rotate(-bpa)
@@ -416,7 +417,7 @@ class AstroData():
             mask = dataformask
         if np.shape(self.data) != np.shape(mask):
             print('The dataformask has a different shape.')
-            return False
+            return
 
         if len(includepix) == 2:
             self.data[(mask < includepix[0]) + (includepix[1] < mask)] = np.nan
@@ -445,7 +446,7 @@ class AstroData():
         """
         if np.ndim(self.data) != 3 or self.v is None:
             print('Data must be 3D with the v, y, and x axes.')
-            return False
+            return
 
         if len(coords) > 0:
             xlist, ylist = coord2xy(coords, self.center) * 3600.
@@ -705,6 +706,8 @@ class AstroFrame():
             d.fitsimage_org = [d.fitsimage_org] * d.n
         if type(d.sigma_org) is not list:
             d.sigma_org = [d.sigma_org] * d.n
+        if type(d.beam_org) is not list:
+            d.beam_org = [d.beam_org] * d.n
         if type(d.fitsheader) is not list:
             d.fitsheader = [d.fitsheader] * d.n
         if type(d.pv) is not list:
@@ -776,6 +779,14 @@ class AstroFrame():
                         header['BMIN'] = d.beam[i][1] / 3600
                     d.data[i] = d.data[i] * Jy2K(header=header)
                     d.sigma[i] = d.sigma[i] * Jy2K(header=header)
+                if self.pv and None not in d.beam[i]:
+                    bmaj, bmin, bpa = d.beam_org[i] = d.beam[i]
+                    if d.pvpa[i] is None:
+                        d.pvpa[i] = bmaj
+                        print('pvpa is not specified. pvpa=bmaj is assumed.')
+                    p = np.radians(bpa - d.pvpa[i])
+                    b = 1 / np.hypot(np.cos(p) / bmaj, np.sin(p) / bmin)
+                    d.beam[i] = np.array([b, d.v[1] - d.v[0], 0])
             d.Tb[i] = False
             d.cfactor[i] = 1
             if d.fitsimage[i] is not None:
@@ -793,6 +804,7 @@ class AstroFrame():
             d.bunit = d.bunit[0]
             d.fitsimage_org = d.fitsimage_org[0]
             d.sigma_org = d.sigma_org[0]
+            d.beam_org = d.beam_org[0]
             d.fitsheader = d.fitsheader[0]
             d.pv = d.pv[0]
             d.pvpa = d.pvpa[0]
